# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.core.management import call_command
import os

fixture_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '../fixtures'))
fixture_filename = 'data.json'


def load_fixture(apps, schema_editor):
    fixture_file = os.path.join(fixture_dir, fixture_filename)
    call_command('loaddata', fixture_file) 


class Migration(migrations.Migration):

    dependencies = [
        ('crdist', '0001_initial'),
    ]

    operations = [
                  migrations.RunPython(load_fixture),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Canton',
            fields=[
                ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True, serialize=False)),
                ('code', models.CharField(max_length=16, unique=True, verbose_name='Code')),
                ('name', models.CharField(max_length=64, verbose_name='Name')),
            ],
            options={
                'verbose_name_plural': 'Cantons',
                'verbose_name': 'Canton',
            },
        ),
        migrations.CreateModel(
            name='District',
            fields=[
                ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True, serialize=False)),
                ('code', models.CharField(max_length=16, unique=True, verbose_name='Code')),
                ('name', models.CharField(max_length=64, verbose_name='Name')),
                ('canton', models.ForeignKey(verbose_name='Canton', to='crdist.Canton')),
            ],
            options={
                'verbose_name_plural': 'Districts',
                'verbose_name': 'District',
            },
        ),
        migrations.CreateModel(
            name='Province',
            fields=[
                ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True, serialize=False)),
                ('code', models.CharField(max_length=16, unique=True, verbose_name='Code')),
                ('name', models.CharField(max_length=64, verbose_name='Name')),
            ],
            options={
                'verbose_name_plural': 'Provinces',
                'verbose_name': 'Province',
            },
        ),
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True, serialize=False)),
                ('name', models.CharField(max_length=64, unique=True, verbose_name='Name')),
            ],
            options={
                'verbose_name_plural': 'Regions',
                'verbose_name': 'Region',
            },
        ),
        migrations.AddField(
            model_name='district',
            name='region',
            field=models.ForeignKey(verbose_name='Region', null=True, to='crdist.Region'),
        ),
        migrations.AddField(
            model_name='canton',
            name='province',
            field=models.ForeignKey(verbose_name='Province', to='crdist.Province'),
        ),
    ]



'''
Created on 16/12/2015

@author: luisza
'''


from django.forms.widgets import Select
from django.forms.utils import flatatt
from django.utils.safestring import mark_safe
from django.utils.html import format_html

from crdist.models import Province, Canton, District
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from crdist.utils import obj_2_hexa


class DistrictSelect(Select):

    def render(self, name, value, attrs=None, choices=()):
        prov_value = []
        dist = None
        canton = None
        prov = None
        if value is None or value==-1 or value=="-1":
            value = ''
        else:
            dist = District.objects.get(pk=value)
            canton = dist.canton.pk
            prov_value.append(str(dist.canton.province.pk))
            prov = dist.canton.province.pk

        prov_attrs = self.build_attrs(attrs, name='province_' + name)
        prov_attrs['id'] = 'id_province_' + name
        prov_attrs['onchange'] = 'load_canton(this, undefined)'
        output = ['<label for="%s">%s: </label>' % (prov_attrs['id'], _('Province')) ,
                  format_html('<select{}>', flatatt(prov_attrs))]
        output.append(self.render_province(prov_value))
        output.append('</select>')

        cant_att = {'id': 'div_canton_' + name, 'href': reverse('crdist_canton') + '?name=' + name}
        dist_att = {'id': 'div_district_' + name, 'href': reverse('crdist_district') + '?name=' + name }

        if attrs:
            nattrs = self.build_attrs(attrs)
            del nattrs['id']
            if nattrs:
                nattrs = obj_2_hexa(nattrs)
                dist_att['href'] = dist_att['href'] + "&attrs=" + nattrs
                cant_att['href'] = cant_att['href'] + "&attrs=" + nattrs

        output.append(format_html('<div{}></div>', flatatt(cant_att)))
        output.append(format_html('<div{}></div>', flatatt(dist_att)))
        if not dist is None:
            output.append("""<input type="hidden" name="err_canton_%s" class="crdist_onerror" value="%d"
            initial="%d" />""" % (name, prov, canton))
            output.append("""<input type="hidden" name="err_district_%s" class="crdist_onerror" value="%d" 
            initial="%d" />""" % (name, canton, dist.pk))
        return mark_safe('\n'.join(output))

    def render_province(self, selected_value=[]):
        options = [self.render_option(selected_value, -1, '  ---  ')]
        for prov in Province.objects.all():
            options.append(self.render_option(selected_value, prov.pk, prov.name))
        return '\n'.join(options)
    
    class Media:
        js = ('crdist/form.%sjs' % ("min." if not settings.DEBUG else ""),)




from django.shortcuts import render

# Create your views here.

from django.http import JsonResponse
from crdist.models import Canton, District
from django.utils.translation import ugettext_lazy as _
from django.utils.safestring import mark_safe
from django.forms.utils import flatatt
from crdist.utils import str_2_obj


def render_option(option_list, name, label=" ", function_load="",
                  prefix="", initial=0, attrs=None):

    attrs = flatatt(attrs) if attrs is not None else ""
    options = []
    for option in option_list:
        options.append('<option value="%d" %s >%s</option>' % (option.pk, 'selected="selected"' if initial == option.pk else "", option.name))

    label = '<label for="%s">%s: </label>' % ('id_' + prefix + name, label)
    if options:
        return mark_safe(label + """ <select %s id="%s" name="%s" onchange="%s">
        <option value="-1"> --- </option> %s 
        </select>""" % (attrs , 'id_' + prefix + name, prefix + name, function_load, " ".join(options)))

    return str(_("Not available"))


def get_canton(request):
    name = request.GET.get('name', '')
    canton = Canton.objects.filter(province__pk=request.GET.get('province', "0"))
    initial = request.GET.get("initial", "0")
    attrs = str_2_obj(request.GET.get('attrs', ''))

    try:
        initial = int(initial)
    except:
        initial = 0
    return JsonResponse({'id':'div_canton_' + name,
                         'content': render_option(canton, name,
                                                  label=_("Canton"),
                                                  function_load="load_district(this, undefined)",
                                                  prefix="canton_",
                                                  initial=initial,
                                                  attrs=attrs)})


def get_distric(request):
    name = request.GET.get('name', '')
    dists = District.objects.filter(canton__pk=request.GET.get('canton', "0"))
    initial = request.GET.get("initial", "0")
    attrs = str_2_obj(request.GET.get('attrs', ''))
    try:
        initial = int(initial)
    except:
        initial = 0
    return JsonResponse({'id':'div_district_' + name,
                         'content': render_option(dists, name,
                                                  label=_("District"),
                                                  function_load=" ",
                                                  prefix="",
                                                  initial=initial,
                                                  attrs=attrs)})





# encoding: utf-8
from __future__ import unicode_literals

from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

class CrdistConfig(AppConfig):
    name = 'crdist'
    verbose_name = _("Costa Rican distribution")



'''
Created on 16/12/2015

@author: luisza
'''

from setuptools import setup, find_packages
import os

CLASSIFIERS = [
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.4',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
]

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

# Dynamically calculate the version based on django.VERSION.
version = __import__('crdist').get_version()

setup(
    author='Luis Zarate Montero',
    author_email='luis.zarate@solvosoft.com',
    name='crdist',
    version=version,
    description='Costa Rican Geografic distribution for model admin in Django.',
    long_description=README,
    url='https://github.com/solvo/crdist',
    license='GNU General Public License',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    install_requires=[
        'setuptools',
        'django>=1.7',
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False
)



from django.contrib import admin

# Register your models here.

from crdist.models import District, Canton, Province
from crdist.widgets import DistrictSelect
from django import forms

admin.site.register([District, Canton, Province])

